﻿using System.Web.Mvc;
using System.Drawing;
using SelectPdf.Samples.Models;

namespace SelectPdf.Samples.Controllers
{
    public class PdfTemplatesController : Controller
    {
        // GET: PdfTemplates
        public ActionResult Index()
        {
            return View();
        }

        [HttpPost]
        public ActionResult SubmitAction(FormCollection collection)
        {
            // create a new pdf document
            PdfDocument doc = new PdfDocument();

            // create a new pdf font
            PdfFont font = doc.AddFont(PdfStandardFont.Helvetica);
            font.Size = 24;

            // add a new page to the document
            PdfPage page = doc.AddPage();

            // create a new text element and add it to the page
            PdfTextElement text = new PdfTextElement(0, 0, Helper.SomeLongText(), font);
            page.Add(text);

            // get image path
            string imgFile = Server.MapPath("~/files/logo.png");

            // add a template containing an image
            // the image should repeat on all pdf pages automatically
            PdfTemplate template1 = doc.AddTemplate(new RectangleF(100, 0, 400, 150));
            PdfImageElement img1 = new PdfImageElement(0, 0, imgFile);
            template1.Add(img1);

            // add another template containing an image behind the existing page elements
            // (under the text) the image should repeat on all pdf pages automatically
            PdfTemplate template2 = doc.AddTemplate(new RectangleF(100, 200, 400, 150));
            template2.Background = true;
            PdfImageElement img2 = new PdfImageElement(0, 0, imgFile);
            template2.Add(img2);

            // save pdf document
            byte[] pdf = doc.Save();

            // close pdf document
            doc.Close();

            // return resulted pdf document
            FileResult fileResult = new FileContentResult(pdf, "application/pdf");
            fileResult.FileDownloadName = "Document.pdf";
            return fileResult;
        }
    }
}